# ----------------------------------------------- #
# Lactobacillus kunkeei example #
# ----------------------------------------------- #
# Here is an example to calculate the genomic gc3
# input the one multifasta files to calculate genomic gc3
genomic_gc3(system.file("sequences/L_kunkeei_genome_cds.ffn",package="sscu"))Run the code above in your browser using DataLab