# ----------------------------------------------- #
# Lactobacillus kunkeei example #
# ----------------------------------------------- #
# Here is an example to load the data included in the sscu package
# input the two multifasta files to calculate sscu
s_index(high_cds_file=system.file("sequences/L_kunkeei_highly.ffn",package="sscu"),genomic_cds_file=system.file("sequences/L_kunkeei_genome_cds.ffn",package="sscu"))
# alternatively, input one multifasta file and gc3 content to calculate sscu
s_index(high_cds_file=system.file("sequences/L_kunkeei_highly.ffn",package="sscu"),gc3=0.76)
# if you want to load your own data, you just specify the file path for your input as these examples
# s_index(high_cds_file="/home/yu/Data/codon_usage/bee_endosymbionts/sharp_40_highly_dataset/Bin2.ffn",genomic_cds_file="/home/yu/Data/codon_usage/bee_endosymbionts/cds_filtered/Bin2.ffn")
# s_index(high_cds_file="/home/yu/Data/codon_usage/bee_endosymbionts/sharp_40_highly_dataset/Bin2.ffn",gc3=0.76)Run the code above in your browser using DataLab